# Eunomia Core

Eunomia core package with minimal required dependencies.

## Overview

This package contains shared functionality across the main [Eunomia][eunomia-github] package and all Eunomia SDKs.

It includes common data models, utility functions, and types that ensure consistency across all Eunomia components.

## Installation

```bash
pip install eunomia-core
```

## Usage

```python
from eunomia_core import *
```

## Documentation

For detailed usage, check out the package [documentation][docs].

[eunomia-github]: https://github.com/whataboutyou-ai/eunomia
[docs]: https://whataboutyou-ai.github.io/eunomia/api/core/
